@@ -54,7 +54,7 @@ test_that("ki_timeseries_values returns table with data", {
     start_date = "2015-12-01",
     end_date = "2018-01-01"
   )
-  expect_is(ts_vals, c("tbl_df", "tbl", "data.frame"))
+  expect_type(ts_vals, "list")
 })
 
 test_that("ki_timeseries_values can take a vector of ts_ids and return list of tables", {
@@ -68,7 +68,7 @@ test_that("ki_timeseries_values can take a vector of ts_ids and return list of t
     end_date = "2018-01-01"
   )
 
-  expect_is(ts_vals, c("tbl_df", "tbl", "data.frame"))
+  expect_type(ts_vals, "list")
   expect(
     length(unique(ts_vals$ts_name)) == 2,
     failure_message = "Timeseries values query for multiple ts_ids didn't return multiple ts_names"
@@ -91,3 +91,43 @@ test_that("ki_timeseries_values returns three columns (two static) by default",
     failure_message = "Timeseries values query did not return expected columns."
   )
 })
+
+test_that("ki_timeseries_values accepts custom return fields (vector or string)", {
+  skip_if_net_down()
+  skip_if_exp_down()
+
+  cust_ret_str <- "Timeseries Comment"
+  cust_ret_v <- c("Timeseries Comment")
+
+  fake_ret_str <- "metadatathatdoesntactuallexist"
+
+  ts_cust_retr <- ki_timeseries_values(
+    hub = example_hub,
+    ts_id = test_ts_ids[[1]],
+    start_date = "2015-12-01",
+    end_date = "2018-01-01",
+    return_fields = cust_ret_str
+  )
+
+  ts_cust_retr2 <- ki_timeseries_values(
+    hub = example_hub,
+    ts_id = test_ts_ids[[1]],
+    start_date = "2015-12-01",
+    end_date = "2018-01-01",
+    return_fields = cust_ret_str
+  )
+
+  expect_type(ts_cust_retr, "list")
+  expect_type(ts_cust_retr2, "list")
+  expect_equal(ts_cust_retr, ts_cust_retr2)
+
+  expect_error(
+    ts_cust_retr2 <- ki_timeseries_values(
+      hub = example_hub,
+      ts_id = test_ts_ids[[1]],
+      start_date = "2015-12-01",
+      end_date = "2018-01-01",
+      return_fields = fake_ret_str
+    )
+  )
+})
